@@ -59,7 +59,7 @@ class EasyTk(object):
         self.all_widgets.setdefault("root", child)
         self.all_masters.setdefault("root",self.create_master(root,'root'))
 
-    def create_master(self,master_obj,name):
+    def create_master(self,master_obj,name=""):
         master = TkMaster()
         master.obj = master_obj
         master.name = name
